@@ -5,6 +5,7 @@ from functools import wraps
 from io import BytesIO
 import json
 import logging
+import mimetypes
 import os
 from pathlib import Path
 import pickle
@@ -1470,14 +1471,18 @@ class ServiceDrive(GoogleBase):
         elif not filepath.is_file():
             raise GoogleDriveError("Filename '%s' does not exist" % filename)
 
-        query_string = f"name = '{filename}' and '{folder_id}' in parents"
+        query_string = f"name = '{filepath.name}' and '{folder_id}' in parents"
         target_file = self.drive_search_files(query=query_string, recurse=True)
+        guess_mimetype = mimetypes.guess_type(str(filepath.absolute()))
+        file_mimetype = guess_mimetype[0] if guess_mimetype else "*/*"
+        media = MediaFileUpload(
+            filepath.absolute(), mimetype=file_mimetype, resumable=True
+        )
         file_metadata = {
             "name": filepath.name,
             "parents": [folder_id],
-            "mimeType": "*/*",
+            "mimeType": file_mimetype,
         }
-        media = MediaFileUpload(filepath.absolute(), mimetype="*/*", resumable=True)
         if len(target_file) == 1 and overwrite:
             self.logger.info("Overwriting file '%s' with new content", filename)
             file = (
@@ -1487,18 +1492,22 @@ class ServiceDrive(GoogleBase):
             )
             return file.get("id", None)
         elif len(target_file) == 1 and not overwrite:
-            self.logger.info("Not uploading new copy of file '%s'", filename)
+            self.logger.warn("Not uploading new copy of file '%s'", filepath.name)
             return None
         elif len(target_file) > 1:
-            self.logger.warning(
+            self.logger.warn(
                 "Drive already contains '%s' copies of file '%s'. Not uploading again."
-                % (len(target_file), filename)
+                % (len(target_file), filepath.name)
             )
             return None
         else:
             file = (
                 service.files()
-                .create(body=file_metadata, media_body=media, fields="id")
+                .create(
+                    body=file_metadata,
+                    media_body=media,
+                    fields="id",
+                )
                 .execute()
             )
             return file.get("id", None)
